#
# spec file for package python-asciimatics
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-asciimatics
Version:        1.15.0
Release:        2.2
Summary:        Package to replace curses and create ASCII animations
License:        Apache-2.0
URL:            https://github.com/peterbrittain/asciimatics
Source:         https://files.pythonhosted.org/packages/source/a/asciimatics/asciimatics-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pillow >= 2.7.0
Requires:       python-curses
Requires:       python-pyfiglet >= 0.7.2
Requires:       python-wcwidth
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Pillow >= 2.7.0}
BuildRequires:  %{python_module curses}
BuildRequires:  %{python_module pyfiglet >= 0.7.2}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wcwidth}
# /SECTION
%python_subpackages

%description
Asciimatics is a package to help people create full-screen text UIs
(from interactive forms to ASCII animations) on any platform.

%prep
%autosetup -p1 -n asciimatics-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_image_files requires specific version of Pillow
%pytest -rs -k 'not test_image_files'

%files %{python_files}
%doc CHANGES.rst README.rst doc/source/*.rst doc/source/*.png
%license LICENSE
%{python_sitelib}/asciimatics
%{python_sitelib}/asciimatics-%{version}.dist-info

%changelog
* Wed Aug 14 2024 Dirk Müller <dmueller@suse.com>
- use modern python for sle15
* Thu Oct 26 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.15.0:
  * Dropped support for Python 2, Python 3.9 or above is now required.
  * Added support for ColouredText titles in MultiColumnLIstBox.
  * Added gutter option to Layout.
  * Added speed option to Sprite.
  * Fixed bug where moving focus between Frames resulted in no current focus.
  * Fixed internal state of RadioButton values to be consistent with selection.
  * Fixed handling of zero width modifiers.
  * Fixed image conversion to use modern PIL API and sort off-by-one height
    error.
  * Fixed parser bug returning list instead of colour tuple.
- Drop patch move-to-python3.patch, included upstream.
* Mon Sep 11 2023 Steve Kowalik <steven.kowalik@suse.com>
- Drop patch python-asciimatics-no-mock.patch, has been subsummed.
- Add patch move-to-python3.patch
- Switch to autosetup and pyproject macros.
* Mon Aug 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- update to 1.14.0
  - Added AnsiArtPlayer and AsciinemaPlayer
  - Added dynamically sized, animated sprites to ray caster demo.
  - Added fit parameter to DropdownList.
  - Added support for default colours to AnsiTerminalParser
  - Added VBarChart renderer.
  - BREAKING VISUAL CHANGE: Frame now supports scroll bars without borders, to have no border and
    no scroll bar you now need Frame(has_border=False, can_scroll=False)
  - Added TextBox.hide_cursor and TextBox.auto_scroll properties
  - Added optional diameter parameter to ShootScreen.
  - Improved DropEmitter effect - will now typically take a little longer to clear the screen.
  - Fixed bug in widget focus - eliminated duplicate events and some cases that failed to move focus
  - Fixed bug in clear_widgets() - also reset any focus in the layout.
  - Fixed bug: layout could still be a tab stop with no active widgets.
* Tue Mar  8 2022 pgajdos@suse.com
- add %%autopatch back, it was mistakenly removed
* Mon Mar  7 2022 pgajdos@suse.com
- version update to 1.13.0
  1.13.0
  - -----
  - Added ability to change a `Button`'s text through a `.text` attribute.
  - Added ability to accept a name attribute in the `Button` and `Label` constructors.
  - Added ability to detect job pause/resume and force full screen refresh.
  - Added ability to request terminal default colours using `Screen.COLOUR_DEFAULT`.
  - Converted widgets to a sub-package.
  - Fixed issue with labels in a layout column preventing buttons from being pressed.
  - Fixed issue with visual overrun on Listboxes when there is a label offset.
  - Fixed issue with TextBox hitting IndexError in double buffers due to lack of clipping.
  - Fixed issue with Text/TextBox start columns on reset.
  - Added troubleshooting on terminal colour handling.
  1.12.0
  - -----
  - Added ColouredText objects to handle embedded colour codes in text for some widgets.
  - Added parsers to handle Asciimatics and Ansi Terminal escape sequences.
  - Added ControlCodeParser to create human readable text from raw text with control codes in it.
  - Added readonly logic for Text and TextBox.
  - Added ability to enable/disable widgets by column in layouts.
  - Added left/right/up/down navigation to nearest widget.
  - Added ability to scroll screen/canvas by variable number of lines.
  - Created terminal demo
  - Fixed exception on reinstating NoneType signal handler.
  - Fixed float/int issue with recent builds of pywin32.
  - Fixed issue where setting options changed the selected value (even if it was still present).
  - Fixed erroneous trigger of on_load for all Frames at start of day.
  - Fixed bug where Frames passed on events that they already handled.
  - Fixed bug: Restore current theme on screen resize.
  - Fixed bug in scrolling the screen up.
- deleted patches
  - pr_200.patch (upstreamed)
- added patches
  fix https://github.com/peterbrittain/asciimatics/issues/347
  + python-asciimatics-no-mock.patch
* Sun Aug 16 2020 John Vandenberg <jayvdb@gmail.com>
- Replace nose with pytest
* Wed May 15 2019 Ethan Apodaca <eapodaca@suse.com>
- Update to 1.11.0
  + See changes file for details
* Thu May  9 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Add missing runtime dependency python-curses
- Add CHANGES.rst, README.rst and doc/*.rst to %%doc
- Add patch pr_200.patch to tweak some tests
* Mon Mar  5 2018 toddrme2178@gmail.com
- Initial version
